==> xixiBlog-0.11.zip: xixiBlog/class/global.php <==
<?php
/**
@brief ܥ⥸塼ѤΥ饹᥽åɤ饹
@version $Id: global.php,v 1.6 2004/08/17 10:03:52 minahito Exp $
*/

require_once dirname(__FILE__)."/../framechecker.php";
__exframe_version__('0.8.8');

define("XIXIBLOG_PERPAGE",10);
define("XIXIBLOG_COMMENTS_PERPAGE",40);

class xixiBlog {
	/**
	@brief ꤷ̾Υϥɥ
	*/
	function &getHandler($name)
	{
		global $xoopsModule;
		global $__xixiblog_handelrs_cache__;
		global $xoopsDB;

		$name=strtolower(trim($name));
		if(!isset($__xixiblog_handelrs_cache__[$name])) {
			$class = 'xixiBlog'.ucfirst($name).'Object';

			if(!class_exists($class)) { // ɤ߹
				$filename = XOOPS_ROOT_PATH."/modules/".$xoopsModule->dirname()."/class/".$name.".php";
				if(file_exists($filename)) {
					require_once($filename);
				}
			}

			$handler_class = $class."Handler";
			if(class_exists($handler_class)) {
				$__xixiblog_handelrs_cache__[$name] = new $handler_class($xoopsDB,$class);
			}
			else {
				$__xixiblog_handelrs_cache__[$name] = new exXoopsObjectHandler($xoopsDB,$class);
			}
			return $__xixiblog_handelrs_cache__[$name];
		}
		else {
			return $__xixiblog_handelrs_cache__[$name];
		}
	}

	function getRequestCalendar_date()
	{
		static $calendar_date;
		if($calendar_date>0) return $calendar_date;

		$time=xixiBlog::getRequestdate();
		if($time) {
			$year=intval(date("Y",$time));
			$month=intval(date("m",$time));
			return $calendar_date=mktime(0,0,0,$month,1,$year);
		}
		return false;
	}

	/**
	@brief viewblog.php  detail.php  uid Ⱥǽɽ֥η
	@return array Ϣ ['uid']=>uid ['date']=>ǽ˥ԥååפ줿֥ input_date
	*/
	function getRequestInfo()
	{
		static $request_info;

		require_once "xoops/xoops.php";
		require_once "include/ListController.php";
		require_once dirname(__FILE__)."/../include/BlogFilter.php";

		if(is_array($request_info)) return $request_info;
		
		$request_info=array('uid'=>0,'date'=>0);

		$handler=&xixiBlog::getHandler('blog');

		switch (exXoops::getScriptName($_SERVER['SCRIPT_NAME'])) {
			case "/viewblog.php":
				$filter=new xixiBlogFilter();
				break;

			case "/viewday.php":
				$filter=new xixiBlogDayFilter();
				break;

			case "/viewmonth.php":
				$filter=new xixiBlogMonthFilter();
				break;

			// ե륿ǤϤʤΤǡȼ˽Ƥä return 
			case "/detail.php":
				$id=intval($_GET['id']);
				$blog=&$handler->get($id);
				if(is_object($blog)) {
					$request_info['uid']=$blog->getVar('uid');
					$request_info['date']=$blog->getVar('input_date');
					$request_info['obj']=null;
				}
				return $request_info;
				break;
				
			default:
				return null;
		}

		$listController=new ListController();
		$listController->filter_=&$filter;
		$listController->fetch($handler->getCount($filter->getCriteria()),XIXIBLOG_PERPAGE);
		if(!$listController->filter_->isError()) {
			$cri=$listController->getCriteria();
			$blog=&$handler->getOne($listController->getCriteria(),true);
			if(is_object($blog)) {
				$request_info['uid']=$blog->getVar('uid');
				$request_info['date']=$blog->getVar('input_date');
				$request_info['obj']=&$blog;
			}
		}
		
		return $request_info;
	}
}

?>

==> xixiBlog-0.15.zip: xixiBlog/class/global.php <==
<?php
/**
@brief ܥ⥸塼ѤΥ饹᥽åɤ饹
@version $Id: global.php,v 1.8 2004/10/06 12:53:53 minahito Exp $
*/

require_once dirname(__FILE__)."/../framechecker.php";
__exframe_version__('0.8.8');

define("XIXIBLOG_PERPAGE",10);
define("XIXIBLOG_COMMENTS_PERPAGE",40);

class xixiBlog {
	/**
	@brief ꤷ̾Υϥɥ
	*/
	function &getHandler($name)
	{
		global $xoopsModule;
		global $__xixiblog_handelrs_cache__;
		global $xoopsDB;

		$name=strtolower(trim($name));
		if(!isset($__xixiblog_handelrs_cache__[$name])) {
			$class = 'xixiBlog'.ucfirst($name).'Object';

			if(!class_exists($class)) { // ɤ߹
				$filename = XOOPS_ROOT_PATH."/modules/".$xoopsModule->dirname()."/class/".$name.".php";
				if(file_exists($filename)) {
					require_once($filename);
				}
			}

			$handler_class = $class."Handler";
			if(class_exists($handler_class)) {
				$__xixiblog_handelrs_cache__[$name] = new $handler_class($xoopsDB,$class);
			}
			else {
				$__xixiblog_handelrs_cache__[$name] = new exXoopsObjectHandler($xoopsDB,$class);
			}
			return $__xixiblog_handelrs_cache__[$name];
		}
		else {
			return $__xixiblog_handelrs_cache__[$name];
		}
	}

	function getRequestCalendar_date()
	{
		static $calendar_date;
		if($calendar_date>0) return $calendar_date;

		$time=xixiBlog::getRequestdate();
		if($time) {
			$year=intval(date("Y",$time));
			$month=intval(date("m",$time));
			return $calendar_date=mktime(0,0,0,$month,1,$year);
		}
		return false;
	}

	/**
	@brief viewblog.php  detail.php  uid Ⱥǽɽ֥η
	@return array Ϣ ['uid']=>uid ['date']=>ǽ˥ԥååפ줿֥ input_date
	*/
	function getRequestInfo()
	{
		static $request_info;

		require_once "xoops/xoops.php";
		require_once "include/ListController.php";
		require_once dirname(__FILE__)."/../include/BlogFilter.php";

		if(is_array($request_info)) return $request_info;
		
		$request_info=array('uid'=>0,'date'=>0);

		$handler=&xixiBlog::getHandler('blog');

		switch (exXoops::getScriptName($_SERVER['SCRIPT_NAME'])) {
			case "/viewblog.php":
				$filter=new xixiBlogFilter();
				break;

			case "/viewday.php":
				$filter=new xixiBlogDayFilter();
				break;

			case "/viewmonth.php":
				$filter=new xixiBlogMonthFilter();
				break;

			// ե륿ǤϤʤΤǡȼ˽Ƥä return 
			case "/detail.php":
				$id=intval($_GET['id']);
				$blog=&$handler->get($id);
				if(is_object($blog)) {
					$request_info['uid']=$blog->getVar('uid');
					$request_info['date']=$blog->getVar('input_date');
					$request_info['obj']=null;
				}
				return $request_info;
				break;
				
			default:
				return null;
		}

		$listController=new ListController();
		$listController->filter_=&$filter;
		$listController->fetch($handler->getCount($filter->getCriteria()),XIXIBLOG_PERPAGE);
		if(!$listController->filter_->isError()) {
			$cri=$listController->getCriteria();
			$blog=&$handler->getOne($listController->getCriteria(),true);
			if(is_object($blog)) {
				$request_info['uid']=$blog->getVar('uid');
				$request_info['date']=$blog->getVar('input_date');
				$request_info['obj']=&$blog;
			}
		}
		
		return $request_info;
	}
	
	/**
	@brief ʸСȽ
	@param $str Сʸ
	@retrun СȤԤäʸ֤ޤ
	@note nobunobu  WordPressMe ǤƤ򻲹ͤˤƤޤ
	*/
	function convert_encoding($str,$user_encode='EUC-JP')
	{
		static $charset;
   		if(function_exists('mb_convert_encoding') && !mb_http_input('P')) {
			if(!strlen($charset)) {
    			if(((isset($_POST['charset']) && $_POST['charset']!="") && mb_http_input('P')=="") || strtolower(ini_get("mbstring.http_input"))=="pass")
    				$charset=strtoupper(trim($_POST['charset']));
    			else
    				$charset="auto";

    			if($charset=="auto")
    				$charset = mb_detect_encoding($_POST['title'].$_POST['excerpt'].$_POST['blog_name']);
			}
			
			return mb_convert_encoding($str,$user_encode,$charset);
		}
		return $str;
	}
}

?>
